@@ -24,7 +24,7 @@ from calculate.core.server.gen_pid import search_worked_process
 from calculate.core.setup_cache import Cache as SetupCache
 from calculate.core.server.func import MethodsInterface
 from calculate.lib.cl_template import SystemIni, LayeredIni
-from calculate.lib.datavars import DataVarsError
+from calculate.lib.datavars import DataVarsError, VariableError
 
 from calculate.lib.utils.tools import AddonError
 from calculate.lib.utils.colortext.palette import TextState
